/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file linkgraph_base.h Some typedefs for the main game. */

#ifndef LINKGRAPH_BASE_H
#define LINKGRAPH_BASE_H

#include "linkgraph.h"
#include "linkgraphschedule.h"

typedef LinkGraph::BaseNode Node;
typedef LinkGraph::BaseEdge Edge;

typedef const LinkGraph::BaseNode ConstNode;
typedef const LinkGraph::BaseEdge ConstEdge;


#endif /* LINKGRAPH_BASE_H */
